import Qt 4.7
import "scripts/settings.js" as Settings

Item {
    id: dialog

    property string playbackQuality
    property string downloadQuality
    property string downloadStatus
    property string downloadPath
    property string screenOrientation
    property string mediaPlayer
    property string language

    property variant playbackSettings : [qsTr("Mobile"), qsTr("High Quality")]
    property variant downloadSettings : [qsTr("Mobile"), qsTr("High Quality"), "360p", "480p", "720p"]
    property variant downloadStatusSettings : [qsTr("Automatically"), qsTr("Manually")]
    property variant orientationSettings : [qsTr("Automatic"), qsTr("Landscape"), qsTr("Portrait")]
    property variant mediaPlayerSettings : Controller.kmPlayerInstalled() ? [qsTr("Media Player"), "KMPlayer"] : [qsTr("Media Player")]
    property variant languageSettings : [qsTr("English"), qsTr("German")]

    property string settingToBeChanged

    signal saveClicked

    function getSettings() {
        /* Retrieve relevent settings from the database
          and populate the dialog */

        playbackQuality = Settings.getSetting("playbackQuality");
        downloadQuality = Settings.getSetting("downloadQuality");
        var status = Settings.getSetting("downloadStatus");
        if (status == qsTr("Queued")) {
            downloadStatus = qsTr("Automatically");
        }
        else {
            downloadStatus = qsTr("Manually");
        }
        downloadPath = Settings.getSetting("downloadPath");
        screenOrientation = Settings.getSetting("screenOrientation");
        mediaPlayer = Settings.getSetting("mediaPlayer");
        language = Settings.getSetting("language");
    }

    function saveSettings() {
        /* Save all settings to the database */

        Settings.setSetting("playbackQuality", playbackQuality);
        Settings.setSetting("downloadQuality", downloadQuality);
        Settings.setSetting("screenOrientation", screenOrientation);
        Settings.setSetting("mediaPlayer", mediaPlayer);
        Settings.setSetting("downloadPath", downloadPath);
        Settings.setSetting("language", language);
        Controller.setOrientation(screenOrientation);
        Controller.setMediaPlayer(mediaPlayer);
        YouTube.setPlaybackQuality(playbackQuality);
        DownloadManager.setDownloadQuality(downloadQuality);
        if (downloadStatus == qsTr("Automatically")) {
            Settings.setSetting("downloadStatus", qsTr("Queued"));
        }
        else {
            Settings.setSetting("downloadStatus", qsTr("Paused"));
        }
        displayMessage(qsTr("Your settings have been saved"));
        saveClicked();
    }

    function showDownloadPathDialog() {
        settingToBeChanged = qsTr("Download Path");
        background.opacity = 0;
        settingsLoader.source = "FileChooserDialog.qml";
        settingsLoader.item.title = qsTr("Download Location");
        settingsLoader.item.showButton = true;
        settingsLoader.item.showFiles = false;
        settingsLoader.item.folder = downloadPath;
        settingsLoader.item.opacity = 1;
    }

    function showSettingsList(title, list, currentSetting) {
        /* Show the settings list dialog */

        settingToBeChanged = title;
        background.opacity = 0;
        settingsLoader.source = "SettingsListDialog.qml";
        settingsLoader.item.setSettingsList(title, list, currentSetting);
        settingsLoader.item.opacity = 1;
    }

    function changeSetting(setting) {
        /* Change the appropriate setting in the dialog */

        if (settingToBeChanged == qsTr("Playback Quality")) {
            playbackQuality = setting;
        }
        else if (settingToBeChanged == qsTr("Download Quality")) {
            downloadQuality = setting;
        }
        else if (settingToBeChanged == qsTr("Start Downloads")) {
            downloadStatus = setting;
        }
        else if (settingToBeChanged == qsTr("Download Path")) {
            downloadPath = setting;
        }
        else if (settingToBeChanged == qsTr("Screen Orientation")) {
            screenOrientation = setting;
        }
        else if (settingToBeChanged == qsTr("Media Player")) {
            mediaPlayer = setting;
        }
        else if (settingToBeChanged == qsTr("Language")) {
            language = setting;
        }
    }

    function clearSearches() {
        /* Delete all saved searches from the database */

        if (Settings.clearSearches() == "OK") {
            displayMessage(qsTr("Your saved searches have been cleared"));
        }
        else {
            displayMessage(qsTr("Database error. Unable to clear searches"));
        }
    }

    function rotateDialogs() {
        if (settingsLoader.source != "") {
            settingsLoader.item.state = dialog.state;
        }
    }

    width: 600
    height: 300
    onStateChanged: rotateDialogs()

    Component.onCompleted: getSettings()

    Loader {
        id: settingsLoader

        anchors.centerIn: dialog
        z: 1
        onLoaded: settingsLoader.item.state = dialog.state

        Connections {
            target: settingsLoader.item
            onClose: background.opacity = 1
            onSettingChosen: changeSetting(setting)
        }
    }

    Item {
        id: background

        anchors.fill: dialog

        Behavior on opacity { PropertyAnimation { properties: "opacity"; duration: 500 } }

        Rectangle {
            anchors.fill: background
            color: "black"
            opacity: 0.5
            radius: 10
            border.width: 2
            border.color: activeColor
            smooth: true
        }

        Text {
            id: title

            anchors { horizontalCenter: background.horizontalCenter; top: background.top; topMargin: 10 }
            font.pixelSize: smallFontSize
            color: "white"
            text: qsTr("Settings")
            smooth: true
        }

        Flickable {
            id: flicker

            anchors { fill: background; topMargin: 50; leftMargin: 10; rightMargin: 10; bottomMargin: 90 }
            contentWidth: flicker.width
            contentHeight: divider.height + 20
            clip: true
            flickableDirection: Flickable.VerticalFlick
            boundsBehavior: Flickable.DragOverBounds
            interactive: dialog.state == ""

            Rectangle {
                id: divider

                width: 1
                height: settingColumn.height
                anchors { top: parent.top; horizontalCenter: parent.horizontalCenter }
                color: activeColorLow


                Column {
                    id: settingColumn

                    anchors { right: divider.left; rightMargin: 10; top: divider.top }
                    spacing: 10

                    Text {
                        font.pixelSize: standardFontSize
                        color: "white"
                        horizontalAlignment: Text.AlignRight
                        text: qsTr("Playback quality")
                        smooth: true
                    }

                    Text {
                        font.pixelSize: standardFontSize
                        color: "white"
                        horizontalAlignment: Text.AlignRight
                        text: qsTr("Download quality")
                        smooth: true
                    }

                    Text {
                        font.pixelSize: standardFontSize
                        color: "white"
                        horizontalAlignment: Text.AlignRight
                        text: qsTr("Start downloads")
                        smooth: true
                    }

                    Text {
                        font.pixelSize: standardFontSize
                        color: "white"
                        horizontalAlignment: Text.AlignRight
                        text: qsTr("Download location")
                        smooth: true
                    }

                    Text {
                        font.pixelSize: standardFontSize
                        color: "white"
                        horizontalAlignment: Text.AlignRight
                        text: qsTr("Screen orientation")
                        smooth: true
                    }

                    Text {
                        font.pixelSize: standardFontSize
                        color: "white"
                        horizontalAlignment: Text.AlignRight
                        text: qsTr("Media player")
                        smooth: true
                    }

                    Text {
                        font.pixelSize: standardFontSize
                        color: "white"
                        horizontalAlignment: Text.AlignRight
                        text: qsTr("Language")
                        smooth: true
                    }

                }

                Column {
                    id: valueColumn

                    anchors { left: divider.right; leftMargin: 10; top: divider.top }
                    spacing: 10

                    Text {
                        id: playbackText

                        font.pixelSize: standardFontSize
                        color: playbackMouseArea.pressed ? activeColor : activeColorLow
                        text: playbackQuality
                        smooth: true

                        MouseArea {
                            id: playbackMouseArea

                            width: 200
                            height: 30
                            anchors.centerIn: parent
                            onClicked: showSettingsList(qsTr("Playback Quality"), playbackSettings, playbackQuality)
                        }
                    }

                    Text {
                        id: downloadText

                        font.pixelSize: standardFontSize
                        color: downloadMouseArea.pressed ? activeColor : activeColorLow
                        text: downloadQuality
                        smooth: true

                        MouseArea {
                            id: downloadMouseArea

                            width: 200
                            height: 30
                            anchors.centerIn: parent
                            onClicked: showSettingsList(qsTr("Download Quality"), downloadSettings, downloadQuality)
                        }
                    }

                    Text {
                        id: downloadStatusText

                        font.pixelSize: standardFontSize
                        color: downloadStatusMouseArea.pressed ? activeColor : activeColorLow
                        text: downloadStatus
                        smooth: true

                        MouseArea {
                            id: downloadStatusMouseArea

                            width: 200
                            height: 30
                            anchors.centerIn: parent
                            onClicked: showSettingsList(qsTr("Start Downloads"), downloadStatusSettings, downloadStatus)
                        }
                    }

                    Text {
                        id: downloadPathText

                        width: 240
                        font.pixelSize: standardFontSize
                        color: downloadPathMouseArea.pressed ? activeColor : activeColorLow
                        elide: Text.ElideRight
                        text: downloadPath
                        smooth: true

                        MouseArea {
                            id: downloadPathMouseArea

                            width: downloadPathText.width
                            height: 30
                            anchors.centerIn: parent
                            onClicked: showDownloadPathDialog()
                        }
                    }

                    Text {
                        id: orientationText

                        font.pixelSize: standardFontSize
                        color: orientationMouseArea.pressed ? activeColor : activeColorLow
                        text: screenOrientation
                        smooth: true

                        MouseArea {
                            id: orientationMouseArea

                            width: 200
                            height: 30
                            anchors.centerIn: parent
                            onClicked: showSettingsList(qsTr("Screen Orientation"), orientationSettings, screenOrientation)
                        }
                    }

                    Text {
                        id: playerText

                        font.pixelSize: standardFontSize
                        color: playerMouseArea.pressed ? activeColor : activeColorLow
                        text: mediaPlayer
                        smooth: true

                        MouseArea {
                            id: playerMouseArea

                            width: 200
                            height: 30
                            anchors.centerIn: parent
                            onClicked: showSettingsList(qsTr("Media Player"), mediaPlayerSettings, mediaPlayer)
                        }
                    }

                    Text {
                        id: languageText

                        font.pixelSize: standardFontSize
                        color: languageMouseArea.pressed ? activeColor : activeColorLow
                        text: language
                        smooth: true

                        MouseArea {
                            id: languageMouseArea

                            width: 200
                            height: 30
                            anchors.centerIn: parent
                            onClicked: showSettingsList(qsTr("Language"), languageSettings, language)
                        }
                    }
                }
            }
        }

        PushButton {
            id: clearSearchesButton

            width: 300
            anchors { left: background.left; bottom: background.bottom; margins: 10 }
            showIcon: false
            showText: true
            name: qsTr("Clear saved searches")
            onButtonClicked: clearSearches()
        }

        PushButton {
            id: saveButton

            anchors { right: background.right; bottom: background.bottom; margins: 10 }
            icon: "ui-images/tick.png"

            Connections {
                onButtonClicked: saveSettings()
            }
        }
    }

    MouseArea {
        z: -1
        anchors.fill: dialog
    }

    states: State {
        name: "portrait"
        PropertyChanges { target: dialog; width: 460; height: 500 }
        PropertyChanges { target: downloadPathText; width: 180 }
        PropertyChanges { target: clearSearchesButton; width: 440; anchors.bottomMargin: 90 }
        PropertyChanges { target: saveButton; width: 440 }
    }
}
